<?php
/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Chandravadana Kandregula
 * Code Release Version: 1.0.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * @module Pinpoint_DeliveryMessage;
 */

namespace Pinpoint\DeliveryMessage\Api;

use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Exception\NoSuchEntityException;
use Pinpoint\DeliveryMessage\Api\Data\DeliveryMessageInterface;

/**
 * CMS block CRUD interface.
 * @api
 * @since 100.0.2
 */
interface DeliveryMessageRepositoryInterface
{
    /**
     * Save block.
     *
     * @param DeliveryMessageInterface $message
     * @return DeliveryMessageInterface
     * @throws LocalizedException
     */
    public function save(DeliveryMessageInterface $message);

    /**
     * Retrieve block.
     *
     * @param int $messageId
     * @return DeliveryMessageInterface
     * @throws LocalizedException
     */
    public function getById(int $messageId);

    /**
     * Delete block.
     *
     * @param DeliveryMessageInterface $message
     * @return bool true on success
     * @throws LocalizedException
     */
    public function delete(DeliveryMessageInterface $message);

    /**
     * Delete block by ID.
     *
     * @param int $messageId
     * @return bool true on success
     * @throws NoSuchEntityException
     * @throws LocalizedException
     */
    public function deleteById(int $messageId);
}
