<?php
/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Chandravadana Kandregula
 * Code Release Version: 1.0.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * Class GenericButton
 * @package Pinpoint\DeliveryMessage\Block\Adminhtml\DeliveryMessage\Edit;
 */
namespace Pinpoint\DeliveryMessage\Block\Adminhtml\DeliveryMessage\Edit;

use Magento\Backend\Block\Widget\Context;
use Magento\Cms\Api\BlockRepositoryInterface;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\Exception\NoSuchEntityException;
use Pinpoint\DeliveryMessage\Api\DeliveryMessageRepositoryInterface;

class GenericButton
{
    /**
     * @var Context
     */
    protected $context;

    /**
     * @var BlockRepositoryInterface
     */
    protected $blockRepository;
    /**
     * @var DeliveryMessageRepositoryInterface
     */
    private $messageRepository;

    /**
     * @param DeliveryMessageRepositoryInterface $messageRepository
     * @param Context $context
     */
    public function __construct(
        DeliveryMessageRepositoryInterface $messageRepository,
        Context $context
    ) {
        $this->context = $context;
        $this->messageRepository = $messageRepository;
    }

    /**
     * Return Message ID
     *
     * @return int
     * @throws LocalizedException
     */
    public function getMessageId()
    {
        if (!is_null($this->context->getRequest()->getParam('id'))) {
            try {
                return $this->messageRepository->getById(
                    $this->context->getRequest()->getParam('id')
                )->getId();
            } catch (NoSuchEntityException $e) {
                return null;
            }
        }
        return null;
    }

    /**
     * Generate url by route and parameters
     *
     * @param   string $route
     * @param   array $params
     * @return  string
     */
    public function getUrl(string $route = '', array $params = [])
    {
        return $this->context->getUrlBuilder()->getUrl($route, $params);
    }
}
