<?php

/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Chandravadana Kandregula
 * Code Release Version: 1.0.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * Class DeliveryMessage
 * @package Pinpoint\DeliveryMessage\Block
 */

namespace Pinpoint\DeliveryMessage\Block;

use Magento\Framework\App\ResourceConnection;
use Magento\Framework\Stdlib\DateTime\DateTimeFactory;
use Magento\Framework\Stdlib\DateTime\TimezoneInterface;
use Magento\Framework\View\Element\Template;
use Magento\Framework\View\Element\Template\Context;
use Pinpoint\DeliveryMessage\Api\Data\DeliveryMessageInterface as DMInterface;
use Pinpoint\DeliveryMessage\Helper\Data;
use Pinpoint\DeliveryMessage\Model\ResourceModel\DeliveryMessage\CollectionFactory;

class DeliveryMessage extends Template
{
    /**
     * @var DeliveryMessage
     */
    protected $deliverymessage;
    /**
     * @var ResourceConnection
     */
    protected $resource;
    /**
     * @var Context
     */
    private $context;
    /**
     * @var CollectionFactory
     */
    private $deliveryMessageFactory;
    /**
     * @var Data
     */
    private $helper;
    /**
     * @var DataObject
     */
    private $message;
    /**
     * @var TimezoneInterface
     */
    private $timezone;
    /**
     * @var DateTimeFactory
     */
    private $dateTimeFactory;

    /**
     * @param Context                                         $context
     * @param CollectionFactory                               $deliveryMessageFactory
     * @param \Pinpoint\DeliveryMessage\Model\DeliveryMessage $deliverymessage
     * @param ResourceConnection                              $resource
     * @param Data                                            $helper
     * @param TimezoneInterface                               $timezone
     * @param DateTimeFactory                                 $dateTimeFactory
     * @param array                                           $data
     */
    public function __construct(
        Context $context,
        CollectionFactory $deliveryMessageFactory,
        \Pinpoint\DeliveryMessage\Model\DeliveryMessage $deliverymessage,
        ResourceConnection $resource,
        Data $helper,
        TimezoneInterface $timezone,
        DateTimeFactory $dateTimeFactory,
        array $data = []
    ) {
        $this->deliverymessage = $deliverymessage;
        $this->resource = $resource;

        parent::__construct(
            $context,
            $data
        );
        $this->context = $context;
        $this->deliveryMessageFactory = $deliveryMessageFactory;
        $this->helper = $helper;
        $this->getDeliveryMessageData();
        $this->timezone = $timezone;
        $this->dateTimeFactory = $dateTimeFactory;
    }

    /**
     * @return DataObject
     */
    public function getDeliveryMessageData()
    {
        if ($this->message === null) {
            $this->message = $this->getMessageFactory()
                ->addFieldToFilter('day', $this->helper->getDay())->getFirstItem();
            if (!$this->message->getData('message_id')) {
                $this->message = $this->getMessageFactory()
                    ->addFieldToFilter('day', 'Default')->getFirstItem();
            }
        }
        return $this->message;
    }

    /**
     * @return \Pinpoint\DeliveryMessage\Model\ResourceModel\DeliveryMessage\Collection
     */
    public function getMessageFactory()
    {
        return $this->deliveryMessageFactory->create()
            ->addFieldToSelect('*')
            ->addFieldToFilter('is_active', 1)
            ->setOrder('message_id', 'desc');
    }

    /**
     * @return string
     */
    public function getDataUrl()
    {
        return $this->getUrl('deliverymessage/json/index');
    }

    /**
     * @return string
     */
    public function getMessageTemplate()
    {
        return 'deliverymessage_template';
    }

    /**
     * @return mixed
     */
    public function getMessageId()
    {
        return $this->message->getData(DMInterface::MESSAGE_ID);
    }

    /**
     * @return mixed
     */
    public function getDeliveryMessage()
    {
        return $this->message->getData(DMInterface::DELIVERY_MESSAGE_BEFORE);
    }

    /**
     * @return mixed
     */
    public function getDeliveryMessageAfter()
    {
        return $this->message->getData(DMInterface::DELIVERY_MESSAGE_AFTER);
    }

    /**
     * @return mixed
     */
    public function getDeliveryMessageMobile()
    {
        return $this->message->getData(DMInterface::MOBILE_MESSAGE_BEFORE);
    }

    /**
     * @return mixed
     */
    public function getDeliveryMessageMobileAfter()
    {
        return $this->message->getData(DMInterface::MOBILE_MESSAGE_AFTER);
    }

    /**
     * @return mixed
     */
    public function getIsActive()
    {
        return $this->message->getData(DMInterface::IS_ACTIVE);
    }

    /**
     * @return mixed
     */
    public function getDay()
    {
        return $this->message->getData(DMInterface::DAY);
    }

    /**
     * @return mixed
     */
    public function getStoreId()
    {
        return $this->message->getData(DMInterface::STORE);
    }

    /**
     * @return mixed
     */
    public function getCutoffTime()
    {
        return $this->message->getData(DMInterface::CUTOFF_TIME);
    }

    /**
     * @return string
     */
    public function getCutoffTimeFormatted()
    {
        return $this->convertTime(
            $this->getCutoffTime()
        );
    }

    /**
     * @return mixed
     */
    public function getTimeFormat()
    {
        return $this->message->getData(DMInterface::TIME_FORMAT);
    }

    /**
     * @return array
     */
    public function getMessages()
    {
        return [
            'delivery_before' => $this->getDeliveryMessage(),
            'delivery_after' => $this->getDeliveryMessageAfter(),
            'delivery_before_mobile' => $this->getDeliveryMessageMobile(),
            'delivery_after_mobile' => $this->getDeliveryMessageMobileAfter(),
        ];
    }

    /**
     * @param string $time
     * @return string
     */
    public function convertTime(string $time)
    {
        $hours = substr($time, 0, 2);
        $minutes = substr($time, 2, 2);

        $time = $hours . ':' . $minutes;
        return $time;
    }

    /**
     * @param string $message
     * @return array
     * @throws NoSuchEntityException
     * @throws \Magento\Framework\Exception\NoSuchEntityException
     */
    public function getMessageData(string $message)
    {
        $messageData = [];
        $stores = explode(',', $this->getStoreId());
        $status = false;
        if (strpos($stores[0], '0') !== false || in_array($this->helper->getCurrentStoreId(), $stores)) {
            $status = true;
        }

        if ($this->getMessageId() === $message && $status) {
            $cutoff = strtotime($this->timezone->date($this->getCutoffTimeFormatted(), null, false)->format('H:i:s'));
            $currentTime = strtotime($this->timezone->date()->format('H:i:s'));

            if ($cutoff > $currentTime) {
                $time = $this->timezone->date(date($cutoff - $currentTime), null, false)->format('H:i:s');

                $messageData = ['cutofftime' => $time,
                                'cutoffdatetime' => $this->timezone->date(date($cutoff))->format('Y/m/d H:i:s'),
                                'currentdatetime' => $this->timezone->date()->format('Y/m/d H:i:s')];
                $standardMessage = str_replace(
                    '<time>',
                    '<span class="countdown"></span>',
                    $this->getDeliveryMessage()
                );
                $mobileMessage = str_replace(
                    '<time>',
                    '<span class="countdown"></span>',
                    $this->getDeliveryMessageMobile()
                );
            } else {
                $standardMessage = str_replace(
                    '<time>',
                    $this->getCutoffTimeFormatted(),
                    $this->getDeliveryMessageAfter()
                );
                $mobileMessage = str_replace(
                    '<time>',
                    $this->getCutoffTimeFormatted(),
                    $this->getDeliveryMessageMobileAfter()
                );
            }

            $messageData = array_merge($messageData, [
                'status' => $status,
                'standard_message' => $standardMessage,
                'mobile_message' => $mobileMessage,
                'nomessage_flag' => false,
                'aftercutoff' => $cutoff
            ]);
            return $messageData;
        } else {
            return [
                'status' => $status,
                'nomessage_flag' => true,
            ];
        }
    }
}
