<?php
/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Chandravadana Kandregula
 * Code Release Version: 1.0.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * Class Delete
 * @package Pinpoint\DeliveryMessage\Controller\Adminhtml\DeliveryMessage;
 */

namespace Pinpoint\DeliveryMessage\Controller\Adminhtml\DeliveryMessage;

use Exception;
use Magento\Backend\App\Action;
use Magento\Backend\Model\View\Result\Redirect;
use Magento\Framework\App\Action\HttpPostActionInterface;
use Magento\Framework\Controller\ResultInterface;
use Pinpoint\DeliveryMessage\Api\Data\DeliveryMessageInterface;
use Pinpoint\DeliveryMessage\Model\DeliveryMessageFactory;

class Delete extends Action implements HttpPostActionInterface
{
    /**
     * @var DeliveryMessageFactory
     */
    private $deliveryMessageFactory;
    /**
     * @var DeliveryMessageInterface
     */
    private $deliveryMessage;

    /**
     * Delete constructor.
     * @param Action\Context $context
     * @param DeliveryMessageInterface $deliveryMessage
     * @param DeliveryMessageFactory $deliveryMessageFactory
     */
    public function __construct(
        Action\Context $context,
        DeliveryMessageInterface $deliveryMessage,
        DeliveryMessageFactory $deliveryMessageFactory
    ) {
        parent::__construct($context);
        $this->deliveryMessageFactory = $deliveryMessageFactory;
        $this->deliveryMessage = $deliveryMessage;
    }

    /**
     * Delete action
     *
     * @return ResultInterface
     */
    public function execute()
    {
        /** @var Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        // check if we know what should be deleted
        $id = $this->getRequest()->getParam('message_id');
        if ($id) {
            try {
                // init model and delete
                $model = $this->deliveryMessageFactory->create();
                $model->load($id);
                $model->delete();
                //$this->deliveryMessageFactory->delete($id);
                // display success message
                $this->messageManager->addSuccessMessage(__('You deleted the Message.'));
                // go to grid
                return $resultRedirect->setPath('deliverymessage/index/');
            } catch (Exception $e) {
                // display error message
                $this->messageManager->addErrorMessage($e->getMessage());
                // go back to edit form
                return $resultRedirect->setPath('deliverymessage/deliverymessage/edit', ['message_id' => $id]);
            }
        }
        // display error message
        $this->messageManager->addErrorMessage(__('We can\'t find a message to delete.'));
        // go to grid
        return $resultRedirect->setPath('deliverymessage/index/');
    }
}
