<?php

/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Chandravadana Kandregula
 * Code Release Version: 1.0.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * Class Save
 * @package Pinpoint\DeliveryMessage\Controller\Adminhtml\DeliveryMessage;
 */

namespace Pinpoint\DeliveryMessage\Controller\Adminhtml\DeliveryMessage;

use Exception;
use Magento\Backend\App\Action;
use Magento\Backend\Model\View\Result\Redirect;
use Magento\Framework\App\Action\HttpPostActionInterface;
use Magento\Framework\Controller\ResultInterface;
use Magento\Framework\Exception\CouldNotSaveException;
use Magento\Framework\Exception\LocalizedException;
use Pinpoint\DeliveryMessage\Api\Data\DeliveryMessageInterface;
use Pinpoint\DeliveryMessage\Model\DeliveryMessage;
use Pinpoint\DeliveryMessage\Model\DeliveryMessageFactory;
use Pinpoint\DeliveryMessage\Model\DeliveryMessageRepository;
use RuntimeException;

class Save extends Action implements HttpPostActionInterface
{
    /**
     * @var DeliveryMessageRepository
     */
    private $deliveryMessageRepository;
    /**
     * @var DeliveryMessageInterface
     */
    private $deliveryMessage;
    /**
     * @var DeliveryMessageFactory
     */
    private $deliveryMessageFactory;

    /**
     * @param Action\Context            $context
     * @param DeliveryMessageFactory    $deliveryMessageFactory
     * @param DeliveryMessageRepository $deliveryMessageRepository
     * @param DeliveryMessageInterface  $deliveryMessage
     */
    public function __construct(
        Action\Context $context,
        DeliveryMessageFactory $deliveryMessageFactory,
        DeliveryMessageRepository $deliveryMessageRepository,
        DeliveryMessageInterface $deliveryMessage
    ) {
        parent::__construct($context);

        $this->deliveryMessageRepository = $deliveryMessageRepository;
        $this->deliveryMessage = $deliveryMessage;
        $this->deliveryMessageFactory = $deliveryMessageFactory;
    }

    /**
     * @return boolean
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('Pinpoint_DeliveryMessage::deliverymessage_save');
    }

    /**
     * Save action
     *
     * @return ResultInterface
     */
    public function execute()
    {
        $data = $this->getRequest()->getPostValue();
        /** @var Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        if ($data) {
            $model = $this->deliveryMessageFactory->create();

            $id = $this->getRequest()->getParam('message_id');
            if ($id) {
                try {
                    $model = $this->deliveryMessageRepository->getById($id);
                    $data['message_id'] = $model->getId();
                } catch (LocalizedException $e) {
                    $this->messageManager->addErrorMessage(__('This message no longer exists.'));
                    return $resultRedirect->setPath('*/*/');
                }
            } else {
                $data['message_id'] = null;
            }

            // get the time field and change it in data
            $time = $this->getRequest()->getParam('cutoff_time');
//            $savedTime = $time[0] . ":" . $time[1];
            $data['cutoff_time'] = $time;
            $data['cutoff_format'] = 12;
            $data['store_id'] = implode(',', $data['store_id']);
            $model->setData($data);

            $this->_eventManager->dispatch(
                'deliverymessage_prepare_save',
                ['deliverymessage' => $model, 'request' => $this->getRequest()]
            );

            try {
                $this->deliveryMessageRepository->save($model);
                return $this->processResultRedirect($model, $resultRedirect, $data);
            } catch (LocalizedException $e) {
                $this->messageManager->addErrorMessage($e->getMessage());
            } catch (RuntimeException $e) {
                $this->messageManager->addErrorMessage($e->getMessage());
            } catch (Exception $e) {
                $this->messageManager->addExceptionMessage($e, __('Something went wrong saving the Message'));
            }
        }
        return $resultRedirect->setPath('*/*/');
    }

    /**
     * Process result redirect
     *
     * @param DeliveryMessageInterface $model
     * @param Redirect                 $resultRedirect
     * @param array                    $data
     * @return Redirect
     * @throws CouldNotSaveException
     */
    private function processResultRedirect(DeliveryMessageInterface $model, Redirect $resultRedirect, array $data)
    {
        if ($this->getRequest()->getParam('back', false) === 'duplicate') {
            $newMessage = $this->deliveryMessageFactory->create(['data' => $data]);
            $newMessage->setId(null);
            $newMessage->setIsActive(false);
            $this->deliveryMessageRepository->save($newMessage);
            $this->messageManager->addSuccessMessage(__('You duplicated the Message.'));
            return $resultRedirect->setPath(
                '*/*/edit',
                [
                    'id' => $newMessage->getId(), '_current' => true
                ]
            );
        }
        if ($this->getRequest()->getParam('back')) {
            $this->messageManager->addSuccessMessage(__('Message saved'));
            return $resultRedirect->setPath('*/*/edit', ['id' => $model->getId(), '_current' => true]);
        }
        return $resultRedirect->setPath('deliverymessage/index/index/');
    }
}
