<?php
/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Chandravadana Kandregula
 * Code Release Version: 1.0.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * Class DeliveryMessage
 * @package Pinpoint\DeliveryMessage\Model;
 */

namespace Pinpoint\DeliveryMessage\Model;

use Magento\Framework\Model\AbstractModel;
use Pinpoint\DeliveryMessage\Api\Data\DeliveryMessageInterface;

class DeliveryMessage extends AbstractModel implements DeliveryMessageInterface
{
    /**
     * @var string
     */
    protected $_eventPrefix = 'deliverymessage';
    /**
     * @var string
     */
    protected $_eventObject = 'deliverymessage';
    /**
     * @var string
     */
    protected $_idFieldName = self::MESSAGE_ID;

    /**
     * @inheritdoc
     *
     * @return void
     */
    protected function _construct()
    {
        $this->_init(\Pinpoint\DeliveryMessage\Model\ResourceModel\DeliveryMessage::class);
    }

    /**
     * Retrieve block id
     *
     * @return int
     */
    public function getId()
    {
        return $this->getData(self::MESSAGE_ID);
    }

    /**
     * @return bool|mixed|null
     */
    public function getIsActive()
    {
        return $this->getData(self::IS_ACTIVE);
    }

    /**
     * @return mixed|string
     */
    public function getDay()
    {
        return $this->getData(self::IS_ACTIVE);
    }

    /**
     * @return mixed|string|null
     */
    public function getCutoffTime()
    {
        return $this->getData(self::IS_ACTIVE);
    }

    /**
     * @return int|mixed
     */
    public function getStoreId()
    {
        return $this->getData(self::STORE);
    }

    /**
     * @return mixed|string
     */
    public function getDeliveryMessageBeforeCutoff()
    {
        return $this->getData(self::DELIVERY_MESSAGE_BEFORE);
    }

    /**
     * @return mixed|string
     */
    public function getDeliveryMessageAfterCutoff()
    {
        return $this->getData(self::DELIVERY_MESSAGE_AFTER);
    }

    /**
     * @return mixed|string
     */
    public function getDeliveryMessageBeforeCutoffMobile()
    {
        return $this->getData(self::MOBILE_MESSAGE_BEFORE);
    }

    /**
     * @return mixed|string
     */
    public function getDeliveryMessageAfterCutoffMobile()
    {
        return $this->getData(self::MOBILE_MESSAGE_AFTER);
    }

    /**
     * @return mixed
     */
    public function getCutoffFormat()
    {
        return $this->getData(self::CUTOFF_TIME);
    }

    /**
     * @param string $dmbc
     * @return mixed|DeliveryMessage
     */
    public function setDeliveryMessageBeforeCutoff(string $dmbc)
    {
        return $this->setData(self::DELIVERY_MESSAGE_BEFORE, $dmbc);
    }

    /**
     * @param string $dmac
     * @return mixed|DeliveryMessage
     */
    public function setDeliveryMessageAfterCutoff(string $dmac)
    {
        return $this->setData(self::DELIVERY_MESSAGE_AFTER, $dmac);
    }

    /**
     * @param string $dmbcm
     * @return mixed|DeliveryMessage
     */
    public function setDeliveryMessageBeforeCutoffMobile(string $dmbcm)
    {
        return $this->setData(self::MOBILE_MESSAGE_BEFORE, $dmbcm);
    }

    /**
     * @param string $dmacm
     * @return mixed|DeliveryMessage
     */
    public function setDeliveryMessageAfterCutoffMobile(string $dmacm)
    {
        return $this->setData(self::MOBILE_MESSAGE_AFTER, $dmacm);
    }

    /**
     * @param boolean $status
     * @return mixed|DeliveryMessage
     */
    public function setIsActive(bool $status)
    {
        return $this->setData(self::IS_ACTIVE, $status);
    }

    /**
     * @param string $day
     * @return mixed|DeliveryMessage
     */
    public function setDay(string $day)
    {
        return $this->setData(self::DAY, $day);
    }

    /**
     * @param string $cTime
     * @return mixed|DeliveryMessage
     */
    public function setCutoffTime(string $cTime)
    {
        return $this->setData(self::CUTOFF_TIME, $cTime);
    }

    /**
     * @param string $cFormat
     * @return mixed|DeliveryMessage
     */
    public function setCutoffFormat(string $cFormat)
    {
        return $this->setData(self::TIME_FORMAT, $cFormat);
    }

    /**
     * @param int $storeId
     * @return mixed|DeliveryMessage
     */
    public function setStoreId(int $storeId)
    {
        return $this->setData(self::STORE, $storeId);
    }

    /**
     * @param string $message
     * @return array
     */
    public function getMessageData(string $message)
    {
        return [
            'status' => true,
            'message' => $message,
            'standard_message' => 'test2',
            'nomessage_flag' => false,
        ];
    }
}
