<?php
/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Chandravadana Kandregula
 * Code Release Version: 1.0.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * Class DeliveryMessage
 * @package Pinpoint\DeliveryMessage\Ui\Component\Form\DataProviders;
 */

namespace Pinpoint\DeliveryMessage\Ui\Component\Form\DataProviders;
use Magento\Framework\App\Request\DataPersistorInterface;
use Magento\Ui\DataProvider\AbstractDataProvider;
use Pinpoint\DeliveryMessage\Model\ResourceModel\DeliveryMessage\CollectionFactory;

class DeliveryMessage extends AbstractDataProvider
{
    /**
     * @var DataPersistorInterface
     */
    private $dataPersistor;

    /**
     * @var array
     */
    protected $loadedData;

    /**
     * DeliveryMessage constructor.
     * @param string $name
     * @param string $primaryFieldName
     * @param string $requestFieldName
     * @param CollectionFactory $collectionFactory
     * @param DataPersistorInterface $dataPersistor
     * @param array $meta
     * @param array $data
     */
    public function __construct(
        string $name,
        string $primaryFieldName,
        string $requestFieldName,
        CollectionFactory $collectionFactory,
        DataPersistorInterface $dataPersistor,
        array $meta = [],
        array $data = []
    ) {
        parent::__construct($name, $primaryFieldName, $requestFieldName, $meta, $data);
        $this->collection = $collectionFactory->create();
        $this->dataPersistor = $dataPersistor;
    }
    /**
     * Get data
     *
     * @return array
     */
    public function getData()
    {
        if (isset($this->loadedData)) {
            return $this->loadedData;
        }
        $items = $this->collection->getItems();
        foreach ($items as $message) {
            $this->loadedData[$message->getId()] = $message->getData();
        }

        $data = $this->dataPersistor->get('message');
        if (!empty($data)) {
            $message = $this->collection->getNewEmptyItem();
            $message->setData($data);
            $this->loadedData[$message->getId()] = $message->getData();
        }

        return $this->loadedData;
    }
}
