/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Chandravadana Kandregula
 * Code Release Version: 1.0.0
 * Website: http://www.pinpointdesigns.co.uk
 *
 * @module Pinpoint_DeliveryMessage;
 */

define([
        'jquery',
        'uiComponent',
        'ko',
        'Pinpoint_DeliveryMessage/js/jquery.countdownTimer'
    ], function ($, Component, ko) {
        'use strict';

        var self;
        return Component.extend({
            showMessage: ko.observable(false),
            showStandard: ko.observable(false),
            showMobile: ko.observable(false),
            deliveryMessage: ko.observable(false),
            initialize: function (config) {
                self = this;
                this._super();
                this.deliveryTimeMessage(config.url, config.cutoff, config.message);
            },
            deliveryTimeMessage: function (url, cutoff, message) {
                var requestData = {
                    cutoff: cutoff,
                    message: message
                };
                $.get(url, requestData, function (data) {
                    if (!data.status || data.nomessage_flag) {
                        self.showMessage(false);
                        return;
                    }
                    if(window.matchMedia("(max-width: 767px)").matches) {
                        if (data.mobile_message) {
                            self.deliveryMessage(data.mobile_message);
                            self.showMobile(true);
                            self.showMessage(true);
                            if(data.cutofftime) {
                                self.displayCountdownTimer(data.cutofftime);
                            }
                        }
                    } else {
                        if (data.standard_message) {
                            self.deliveryMessage(data.standard_message);
                            self.showStandard(true);
                            self.showMessage(true);
                            if(data.cutofftime) {
                                self.displayCountdownTimer(data.cutofftime);
                            }
                        }
                    }
                });
            },

            displayCountdownTimer : function (cutoff) {
                var timerSelector = $(".delivery-message .countdown");
                if(timerSelector.length){
                    timerSelector.countdowntimer({
                        hours : cutoff.split(':')[0],
                        minutes : cutoff.split(':')[1],
                        seconds : cutoff.split(':')[2],
                        padZeroes : false,
                        size : "size_md",
                        regexpMatchFormat: "([0-9]{1,2}):([0-9]{1,2}):([0-9]{1,2})",
                        regexpReplaceWith: "$1 hrs $2 mins"
                    });
                }
            }
        });
    }
);
